==> Products.TinyMCE-1.1rc12.zip: Products.TinyMCE-1.1rc12/Products/TinyMCE/skins/tinymce/themes/advanced/langs/ch_dlg.js <==
tinyMCE.addI18n('ch.advanced_dlg',{
about_title:"\u5173\u4E8ETinyMCE",
about_general:"\u5173\u4E8E",
about_help:"\u5E2E\u52A9",
about_license:"\u6388\u6743",
about_plugins:"\u5168\u90E8\u5916\u6302\u7A0B\u5F0F",
about_plugin:"\u5916\u6302\u7A0B\u5F0F",
about_author:"\u4F5C\u8005",
about_version:"\u7248\u672C",
about_loaded:"\u5DF2\u8F7D\u5165\u7684\u5916\u6302\u7A0B\u5F0F",
anchor_title:"\u63D2\u5165/\u7F16\u8F91\u951A\u70B9",
anchor_name:"\u951A\u70B9\u540D\u79F0",
code_title:"HTML\u539F\u59CB\u7A0B\u5F0F\u7801\u7F16\u8F91\u5668",
code_wordwrap:"\u6574\u5B57\u6362\u884C",
colorpicker_title:"\u6311\u9009\u989C\u8272",
colorpicker_picker_tab:"\u9009\u8272\u5668",
colorpicker_picker_title:"\u9009\u8272\u5668",
colorpicker_palette_tab:"\u8272\u76D8",
colorpicker_palette_title:"\u8272\u76D8\u989C\u8272",
colorpicker_named_tab:"\u9884\u8BBE\u7684",
colorpicker_named_title:"\u9884\u8BBE\u7684\u989C\u8272",
colorpicker_color:"\u989C\u8272:",
colorpicker_name:"\u540D\u79F0:",
charmap_title:"\u63D2\u5165\u7279\u6B8A\u7B26\u53F7",
image_title:"\u63D2\u5165/\u7F16\u8F91\u56FE\u7247",
image_src:"\u56FE\u7247\u4F4D\u5740",
image_alt:"\u56FE\u7247\u8BF4\u660E",
image_list:"\u56FE\u7247\u6E05\u5355",
image_border:"\u8FB9\u6846",
image_dimensions:"\u5C3A\u5BF8",
image_vspace:"\u5782\u76F4\u95F4\u8DDD",
image_hspace:"\u6C34\u51C6\u95F4\u8DDD",
image_align:"\u5BF9\u9F50\u65B9\u5F0F",
image_align_baseline:"\u57FA\u7EBF",
image_align_top:"\u4E0A\u65B9\u5BF9\u9F50",
image_align_middle:"\u5C45\u4E2D\u5BF9\u9F50",
image_align_bottom:"\u5E95\u90E8\u5BF9\u9F50",
image_align_texttop:"\u6587\u5B57\u4E0A\u65B9",
image_align_textbottom:"\u6587\u5B57\u4E0B\u65B9",
image_align_left:"\u9760\u5DE6\u5BF9\u9F50",
image_align_right:"\u9760\u53F3\u5BF9\u9F50",
link_title:"\u63D2\u5165/\u7F16\u8F91\u8FDE\u7ED3",
link_url:"\u8FDE\u7ED3\u4F4D\u5740",
link_target:"\u76EE\u6807",
link_target_same:"\u5C06\u8FDE\u7ED3\u7F51\u5740\u5F00\u5728\u6B64\u89C6\u7A97",
link_target_blank:"\u5C06\u8FDE\u7ED3\u7F51\u5740\u5F00\u5728\u65B0\u7A97\u53E3",
link_titlefield:"\u6807\u9898",
link_is_email:"\u60A8\u8F93\u5165\u7684\u7F51\u5740\u5E94\u8BE5\u662F\u4E00\u4E2A\u7535\u5B50\u90AE\u5BC4\u5730\u5740\uFF0C\u662F\u5426\u9700\u8981\u5728\u4F4D\u5740\u524D\u65B9\u52A0\u5165mailto:\uFF1F",
link_is_external:"\u60A8\u8F93\u5165\u7684\u7F51\u5740\u5E94\u8BE5\u662F\u4E00\u4E2A\u5916\u90E8\u8FDE\u7ED3\uFF0C\u662F\u5426\u9700\u8981\u5728\u7F51\u5740\u524D\u65B9\u52A0\u5165http://\uFF1F",
link_list:"\u8FDE\u7ED3\u6E05\u5355"
});

==> Products.TinyMCE-1.1.4.zip: Products.TinyMCE-1.1.4/Products/TinyMCE/skins/tinymce/themes/advanced/langs/ch_dlg.js <==
tinyMCE.addI18n('ch.advanced_dlg',{
about_title:"\u5173\u4E8ETinyMCE",
about_general:"\u5173\u4E8E",
about_help:"\u5E2E\u52A9",
about_license:"\u6388\u6743",
about_plugins:"\u5168\u90E8\u5916\u6302\u7A0B\u5E8F",
about_plugin:"\u5916\u6302\u7A0B\u5E8F",
about_author:"\u4F5C\u8005",
about_version:"\u7248\u672C",
about_loaded:"\u5DF2\u8F7D\u5165\u7684\u5916\u6302\u7A0B\u5E8F",
anchor_title:"\u63D2\u5165/\u7F16\u8F91\u951A\u70B9",
anchor_name:"\u951A\u70B9\u540D\u79F0",
code_title:"HTML\u6E90\u4EE3\u7801\u7F16\u8F91\u5668",
code_wordwrap:"\u6574\u5B57\u6362\u884C",
colorpicker_title:"\u6311\u9009\u989C\u8272",
colorpicker_picker_tab:"\u9009\u8272\u5668",
colorpicker_picker_title:"\u9009\u8272\u5668",
colorpicker_palette_tab:"\u8272\u76D8",
colorpicker_palette_title:"\u8272\u76D8\u989C\u8272",
colorpicker_named_tab:"\u9884\u8BBE\u7684",
colorpicker_named_title:"\u9884\u8BBE\u7684\u989C\u8272",
colorpicker_color:"\u989C\u8272:",
colorpicker_name:"\u540D\u79F0:",
charmap_title:"\u63D2\u5165\u7279\u6B8A\u7B26\u53F7",
image_title:"\u63D2\u5165/\u7F16\u8F91\u56FE\u7247",
image_src:"\u56FE\u7247\u4F4D\u5740",
image_alt:"\u56FE\u7247\u8BF4\u660E",
image_list:"\u56FE\u7247\u6E05\u5355",
image_border:"\u8FB9\u6846",
image_dimensions:"\u5C3A\u5BF8",
image_vspace:"\u5782\u76F4\u95F4\u8DDD",
image_hspace:"\u6C34\u51C6\u95F4\u8DDD",
image_align:"\u5BF9\u9F50\u65B9\u5F0F",
image_align_baseline:"\u57FA\u7EBF",
image_align_top:"\u4E0A\u65B9\u5BF9\u9F50",
image_align_middle:"\u5C45\u4E2D\u5BF9\u9F50",
image_align_bottom:"\u5E95\u90E8\u5BF9\u9F50",
image_align_texttop:"\u6587\u5B57\u4E0A\u65B9",
image_align_textbottom:"\u6587\u5B57\u4E0B\u65B9",
image_align_left:"\u9760\u5DE6\u5BF9\u9F50",
image_align_right:"\u9760\u53F3\u5BF9\u9F50",
link_title:"\u63D2\u5165/\u7F16\u8F91\u94FE\u63A5",
link_url:"\u94FE\u63A5\u5730\u5740",
link_target:"\u76EE\u6807",
link_target_same:"\u5C06\u94FE\u63A5\u7F51\u5740\u5728\u539F\u7A97\u53E3\u4E2D\u6253\u5F00",
link_target_blank:"\u5C06\u94FE\u63A5\u7F51\u5740\u5728\u65B0\u7A97\u53E3\u4E2D\u6253\u5F00",
link_titlefield:"\u6807\u9898",
link_is_email:"\u60A8\u8F93\u5165\u7684\u7F51\u5740\u5E94\u8BE5\u662F\u4E00\u4E2A\u7535\u5B50\u90AE\u4EF6\u5730\u5740\uFF0C\u662F\u5426\u9700\u8981\u5728\u7F51\u5740\u524D\u65B9\u52A0\u5165mailto:\uFF1F",
link_is_external:"\u60A8\u8F93\u5165\u7684\u7F51\u5740\u5E94\u8BE5\u662F\u4E00\u4E2A\u5916\u90E8\u94FE\u63A5\uFF0C\u662F\u5426\u9700\u8981\u5728\u7F51\u5740\u524D\u65B9\u52A0\u5165http://\uFF1F",
link_list:"\u94FE\u63A5\u6E05\u5355"
});
